#!/bin/bash --

## ===========================================================================================================
## livestream-aufnahme_pre.sh - &copy Stefan Bürger, www.stefan-buerger.de
## Script zur Nutzung in TVbrowser oder ähnlichen Anwendungen zu Sender-/Sendungsanzeige
## 
## Nur für LINUX bash...
## livestream-vlc.sh: ........ Livestreams der öffentlich-rechtlichen Mediatheken in VLC ansehen
## ........................... Parameter: Sender (ard, zdf, rbb, rbb-brb, mdr, ndr, wdr,swr, hr, br, sr, neo, 3sat, arte, info, 
## ........................... .................. phoenix, alpha, one, tagesschau, kika, orf1, orf2, orf3, orf-sport, arte-fr)
## ........................... Speicherort: beliebiges Benutzerverzeichnis, verwendet livestream-adresse.inc
## filmschnitt.sh:............ Videodatei schneiden und konvertieren (möglichst nach MP4 1280x720)
## ........................... Parameter: [HDfull|HDready|DVD|Android] Videodatei [Startzeit(hh:mm:ss) [Stopzeit(hh:mm:ss) [FPSx1000 Audiooffset]]]
## ........................... Speicherort: beliebiges Benutzerverzeichnis, verwendet livestream-adresse.inc
## livestream-aufnahme.sh:.... Livestreams der öffentlich-rechtlichen Mediatheken zeitgesteuert aufnehmen/speichern
## ........................... Parameter: Sender(wie bei livestream-vlc.sh) Startzeit(YYYYMMDDhhmm) Dauer(mmm) Name
## ........................... Speicherort: Benutzer-Homeverzeichnis (~/), 
## ........................... ............ verwendet livestream-adresse.inc, livestream-aufnahme.sh, livestream-aufnahme-rm.sh
## livestream-aufnahme-pre.sh: Livestreams der öffentlich-rechtlichen Mediatheken aus TVbrowser zeitgesteuert aufnehmen/speichern
## ........................... Parameter: [remove] Sender (wie bei livestream-vlc.sh), Jahr Monat Tag Stunde Minute Dauer Name
## ........................... Speicherort: Benutzer-Homeverzeichnis (~/), verwendet livestream-adresse.inc
## livestream-aufnahme-rm.sh:. Programmierte Aufnahme löschen
## ........................... Parameter: Sender(wie bei livestream-vlc.sh) Startzeit(YYYYMMDDhhmm) Dauer(mmm) Name
## ........................... Speicherort: Benutzer-Homeverzeichnis (~/), verwendet livestream-adresse.inc
## livestream-adresse.inc:.... Senderliste für  die bash-Scripte
## ........................... Speicherort: Benutzer-Homeverzeichnis (~/)
## 
scriptversion=3.0
scriptdatum=22.11.2023
## ===========================================================================================================
## Parameter
## $1       remove (optional, wird dann mit shift entfernt): Aufnahmeauftrag löschen / xxx (optional Kommando ignorieren)
## $1: Sender    ard, zdf, rbb, rbb-brb, mdr, ndr, wdr,swr, hr, br, sr, neo, 3sat, arte, phoenix, info, alpha, one, tagesschau, kika
## $2...6:  Startjahr 'YYYY', Startmonat '[M]M', Starttag '[D]D', StartStunde '[h]h', Startminute '[m]m'
## $7:      Dauer       '[[h:]m]m:ss'
## $8...16: Name
##
## Einbindung in TVbrowser:
##   <Einstellungen> <Geräte> [Gerät hinzufügen] Name:"Livestream-Mediatheken_der_ÖR-Sender"
##   <Einstellungen> <Geräte> [Gerät konfigurieren] [Livestream-Mediatheken_der_ÖR-Sender]
##     <Einstellungen> <Applikation> - Script zur Aufnahmeprogrammierung:
##       ~/livestream-aufnahme_pre.sh
##     <Einstellungen> <Sender> - Den internen Namen der Sender zuzuordnende externe Namen:
##       ard, zdf, rbb, rbb-brb, mdr, ndr, wdr,swr, hr, br, sr, neo, 3sat, arte, phoenix, info, alpha, one, tagesschau, kika
##     <Einstellungen> <Parameter> - Eintrag "Parameter für Aufnahme":
##       {channel_name_external_quiet} {start_year} {start_month} {start_day} {start_hour} {start_minute} {length_minutes} {title}
##     <Einstellungen> <Parameter> - Eintrag "Parameter für Löschen":
##       remove {channel_name_external_quiet} {start_year} {start_month} {start_day} {start_hour} {start_minute} {length_minutes} {title}
##     <Einstellungen <Einstellungen> - Empfohlene Einstellungen:
##       5 Minuten früher starten - Ausgleich von ungenauer Uhrzeit und gelegentlich etwas voreiligen Sendern
##       35 Minuten später stoppen - Ausgleich von Sendezeit-Überziehungen (meistens 15...30 Minuten, bei Sportsendungen aber oft erheblich mehr)
##       Maximale Anzahl gleichzeitiger Aufnahmen - > 1 erhöht das Risiko gestörter oder abgebrochener Aufzeichnungen
##         !!! manchmal kompletter Stream-Abbruch, 
##         !!! manchmal nur Audio-Abbruch bei weiter aufgezeichnetem Bild, 
##         !!! manchmal Hänger, vor allem bei mehreren Aufzeichnungen aus gleicher Sendergruppe
##         !!! einige Sender sind wegen häufigem Blocking nur eingeschränkt nutzbar, v.a. arte und einige dritte Programme, seltener die übrigen Sender.
##     <OK>
##   <OK>
##
## Hinweis: Die Bearbeitungskonstrukte erscheinen teilweise etwas umständlich, sind aber in bash ohne zusätzliche Sprachelemente nutzbar.
## 

source ~/livestream-adresse.inc

xyear=$2
if [ "$1" = "xxx" ]; then
    echo ignore command
else
    if [ "$1" = "remove" ]; then
        xaction=remove
        shift
    else
        if [ "$1" = "record" ]; then
          shift
        fi
        xaction=record
    fi
    xchannel=$1
    xyear=$2
    # Monat zweistellig
    if [ $3 -le 9 ]; then
        xmonth=0$3
    else
        xmonth=$3
    fi
    # Tag zweistellig
    if [ $4 -le 9 ]; then
        xday=0$4
    else
        xday=$4
    fi
    # Stunde zweistellig
    if [ $5 -le 9 ]; then
        xhour=0$5
    else
        xhour=$5
    fi
    # Minute zweistellig
    if [ $6 -le 9 ]; then
        xminute=0$6
    else
        xminute=$6
    fi
    # Länge (Format einhalten: h:mm:ss, mm und ss darf maximal 2-stellig sein!)
    xlength=$7
    # Name zusammensetzen aus Parameter 8...32
    shift 7
    xname=$1_$2_$3_$4_$5_$6_$7_$8
    if [ $# -gt 8 ]; then
        shift 8
        xname="$xname"_"$1"_"$2"_"$3"_"$4"_"$5"_"$6"_"$7"_"$8"
        if [ $# -gt 8 ]; then
            shift 8
            xname="$xname"_"$1"_"$2"_"$3"_"$4"_"$5"_"$6"_"$7"_"$8"_"$9"
        fi
    fi
    xname="$(echo $xname | zeichenersetzen)"
    # Sprachspezifische Umlaute und Sonderzeichen ersetzen
    namemod

    if [ $xaction = remove ]; then
        echo "livestream-aufnahme-pre.sh: Löschauftrag - $datum_zeit - ${homeverzeichnis}livestream-aufnahme-rm.sh \"$xchannel\" $xyear$xmonth$xday$xhour$xminute $xlength \"$xname\"" >> $aufnahmepfad_absolut$logpfad_relativ./livestream-aufnahme.log
        echo "livestream-aufnahme-pre.sh: Löschauftrag - $datum_zeit - ${homeverzeichnis}livestream-aufnahme-rm.sh \"$xchannel\" $xyear$xmonth$xday$xhour$xminute $xlength \"$xname\""
        echo "/bin/bash ${homeverzeichnis}livestream-aufnahme-rm.sh \"$xchannel\" $xyear$xmonth$xday$xhour$xminute $xlength \"$xname\""
        /bin/bash ${homeverzeichnis}livestream-aufnahme-rm.sh $xchannel $xyear$xmonth$xday$xhour$xminute $xlength "$xname"
    else
        echo "livestream-aufnahme-pre.sh: Aufnahmeauftrag - $datum_zeit - ${homeverzeichnis}livestream-aufnahme.sh \"$xchannel\" $xyear$xmonth$xday$xhour$xminute $xlength \"$xname\"" >> $aufnahmepfad_absolut$logpfad_relativ./livestream-aufnahme.log
        echo "livestream-aufnahme-pre.sh: Aufnahmeauftrag - $datum_zeit - ${homeverzeichnis}livestream-aufnahme.sh \"$xchannel\" $xyear$xmonth$xday$xhour$xminute $xlength \"$xname\""
        echo "/bin/bash ${homeverzeichnis}livestream-aufnahme.sh \"$xchannel\" $xyear$xmonth$xday$xhour$xminute $xlength \"$xname\""
        /bin/bash ${homeverzeichnis}livestream-aufnahme.sh $xchannel $xyear$xmonth$xday$xhour$xminute $xlength "$xname"
    fi
fi
